@@ -8,7 +8,7 @@ from getpass import getpass
 from imghdr import what
 from inspect import cleandoc
 from logging import DEBUG, INFO, basicConfig, getLogger
-from os import environ, getcwd
+from os import environ
 from os.path import exists
 from pathlib import Path
 from sys import exit, stdout
@@ -518,9 +518,9 @@ class Bot(ClientXMPP):
 
         miss = message.type not in self.GROUP_MESSAGE_TYPES
         loop = message.nick == self.nick
-        other = self.nick not in message.text
+        other = self.nick not in message.text and not message.url
 
-        if miss or loop or other:
+        if miss or other or loop:
             return
 
         if message.content.startswith("@"):
